<no title> — CALCEPH - C language 3.4.1 documentation

    int res;
    int j;
    double jd0=2442457;
    double dt1=0.5E0;
    t_calcephbin *peph;
    double P[3];

    /* open the ephemeris file */
    peph = calceph_open("example1.dat");
    if (peph)
    {
      calceph_prefetch(peph);

      calceph_orient_order(peph, jd0, dt1, NAIFID_MOON,
              CALCEPH_USE_NAIFID+CALCEPH_UNIT_RAD+CALCEPH_UNIT_SEC,
              0,
              P);
      for(j=0; j<3; j++) printf("%23.16E\n", P[j]);

      /* close the ephemeris file */
      calceph_close(peph);
    }